==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/vault.py <==
from .. import IconBase


class IconVault(IconBase):
    class_name = "lucide lucide-vault"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "width": "18",
                "height": "18",
                "x": "3",
                "y": "3",
                "rx": "2"
            }
        },
        {
            "circle": {
                "cx": "7.5",
                "cy": "7.5",
                "r": ".5",
                "fill": "currentColor"
            }
        },
        {
            "path": {
                "d": "m7.9 7.9 2.7 2.7"
            }
        },
        {
            "circle": {
                "cx": "16.5",
                "cy": "7.5",
                "r": ".5",
                "fill": "currentColor"
            }
        },
        {
            "path": {
                "d": "m13.4 10.6 2.7-2.7"
            }
        },
        {
            "circle": {
                "cx": "7.5",
                "cy": "16.5",
                "r": ".5",
                "fill": "currentColor"
            }
        },
        {
            "path": {
                "d": "m7.9 16.1 2.7-2.7"
            }
        },
        {
            "circle": {
                "cx": "16.5",
                "cy": "16.5",
                "r": ".5",
                "fill": "currentColor"
            }
        },
        {
            "path": {
                "d": "m13.4 13.4 2.7 2.7"
            }
        },
        {
            "circle": {
                "cx": "12",
                "cy": "12",
                "r": "2"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/vault.py <==
from .. import IconBase


class IconVault(IconBase):
    class_name = "lucide lucide-vault"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "width": "18",
                "height": "18",
                "x": "3",
                "y": "3",
                "rx": "2"
            }
        },
        {
            "circle": {
                "cx": "7.5",
                "cy": "7.5",
                "r": ".5",
                "fill": "currentColor"
            }
        },
        {
            "path": {
                "d": "m7.9 7.9 2.7 2.7"
            }
        },
        {
            "circle": {
                "cx": "16.5",
                "cy": "7.5",
                "r": ".5",
                "fill": "currentColor"
            }
        },
        {
            "path": {
                "d": "m13.4 10.6 2.7-2.7"
            }
        },
        {
            "circle": {
                "cx": "7.5",
                "cy": "16.5",
                "r": ".5",
                "fill": "currentColor"
            }
        },
        {
            "path": {
                "d": "m7.9 16.1 2.7-2.7"
            }
        },
        {
            "circle": {
                "cx": "16.5",
                "cy": "16.5",
                "r": ".5",
                "fill": "currentColor"
            }
        },
        {
            "path": {
                "d": "m13.4 13.4 2.7 2.7"
            }
        },
        {
            "circle": {
                "cx": "12",
                "cy": "12",
                "r": "2"
            }
        }
    ]
}
